# sais-notify

## 介绍
SAIS 消息通知服务Python SDK，方便开发者快速集成消息通知服务。

### 功能

**DONE：**
- 飞书用户文本通知
- 飞书用户富文本通知

**TODO：**
- 飞书用户文本通知
- 飞书用户富文本通知

### 使用

> 安装sais-notify

```bash 
pip install sais-notify
```

> 使用sais-notify

```
todo
```

## 代码结构
```
├── README.md
├── pyproject.toml
└── sais
    ├── __init__.py
    └── notify
        ├── __init__.py
        ├── auth
        │   ├── __init__.py
        │   └── auth_info.py
        ├── clients
        │   ├── __init__.py
        │   └── notify_client.py
        ├── config
        │   ├── __init__.py
        │   ├── const.py
        │   └── version.py
        ├── handler
        │   ├── __init__.py
        │   └── message_handler.py
        ├── model
        │   ├── __init__.py
        │   └── message_model.py
        ├── requirements.txt
        └── types
            └── __init__.py
```

## 更多
**联系我们：** SAIS 团队
